@@ -8,7 +8,7 @@ from nonebot.internal.matcher import Matcher
 from nonebot_plugin_mahjong_utils.errors import BadRequestError
 
 
-def handle_error(matcher: Type[Matcher]):
+def handle_error(matcher: Type[Matcher], silently: bool = False):
     def decorator(func):
         @wraps(func)
         async def wrapped_func(*args, **kwargs):
@@ -17,13 +17,15 @@ def handle_error(matcher: Type[Matcher]):
             except MatcherException as e:
                 raise e
             except BadRequestError as e:
-                await matcher.finish(e.message)
+                if not silently:
+                    await matcher.finish(e.message)
             except ActionFailed as e:
                 # 避免当发送消息错误时再尝试发送
                 logger.exception(e)
             except Exception as e:
                 logger.exception(e)
-                await matcher.finish(f"内部错误：{type(e)}{str(e)}")
+                if not silently:
+                    await matcher.finish(f"内部错误：{type(e)}{str(e)}")
 
         return wrapped_func
 
